﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Collections.ObjectModel;
using System.ComponentModel;
using Infragistics.Windows.DataPresenter;
using System.Diagnostics;
using Infragistics.Windows.Controls;
using Infragistics.Windows;

namespace DataCarouselScrollOnTouch
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        private TouchPoint prevPoint;

        public MainWindow()
        {
            InitializeComponent();

            DataContext = Data.GetData(50, 10, 100);
        }
        
        private void productCarousel_TouchMove(object sender, TouchEventArgs e)
        {
            XamCarouselPanel panel = (sender as XamDataCarousel).Tag as XamCarouselPanel;
            if (prevPoint == null)
                prevPoint = e.GetTouchPoint(sender as UIElement);

            if (prevPoint != null && Math.Abs(prevPoint.Position.X - e.GetTouchPoint(sender as UIElement).Position.X) > 50)
            {
                Debug.WriteLine(prevPoint.Position.X);
                if (prevPoint.Position.X > e.GetTouchPoint(sender as UIElement).Position.X)
                {
                    panel.ExecuteCommand(XamCarouselPanelCommands.NavigateToNextItem);
                }
                else
                {
                    panel.ExecuteCommand(XamCarouselPanelCommands.NavigateToPreviousItem);
                }

                prevPoint = e.GetTouchPoint(sender as UIElement);
            }
        }

        private void productCarousel_Loaded(object sender, RoutedEventArgs e)
        {
            XamCarouselPanel panel = Utilities.GetDescendantFromType(sender as DependencyObject, typeof(XamCarouselPanel), true) as XamCarouselPanel;
            (sender as XamDataCarousel).Tag = panel;
        }

        private void productCarousel_TouchUp(object sender, TouchEventArgs e)
        {
            prevPoint = null;
        }
    }


    public class Data : INotifyPropertyChanged
    {
        private int open;
        private int close;
        private int high;
        private int low;
        private int value;
        private string label;

        public string Label
        {
            get { return label; }
            set
            {
                label = value;
                PropChanged("Label");
            }
        }

        public int Open
        {
            get { return open; }
            set
            {
                open = value;
                PropChanged("Open");
            }
        }

        public int Close
        {
            get { return close; }
            set
            {
                close = value;
                PropChanged("Close");
            }
        }

        public int High
        {
            get { return high; }
            set
            {
                high = value;
                PropChanged("High");
            }
        }

        public int Low
        {
            get { return low; }
            set
            {
                low = value;
                PropChanged("Low");
            }
        }

        public int Value
        {
            get { return value; }
            set
            {
                this.value = value;
                PropChanged("Value");
            }
        }

        public static ObservableCollection<Data> GetData(int points, int rangeStart, int rangeEnd)
        {
            ObservableCollection<Data> data = new ObservableCollection<Data>();
            Random r = new Random();
            for (int i = 0; i < points; i++)
            {
                data.Add(new Data
                {
                    Label = "Item " + i,
                    Open = r.Next(rangeStart, rangeEnd),
                    Close = r.Next(rangeStart, rangeEnd),
                    High = r.Next(rangeStart, rangeEnd),
                    Low = r.Next(rangeStart, rangeEnd),
                    Value = r.Next(rangeStart, rangeEnd),
                });
            }

            return data;
        }

        public event PropertyChangedEventHandler PropertyChanged;

        public void PropChanged(string name)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(name));
        }
    }
}
